# GroupFolder

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**folder** | [**InlineResponse200**](InlineResponse200.md) |  | [optional] 
**group** | [**InlineResponse2001**](InlineResponse2001.md) |  | [optional] 
**permission** | **int** | Group&#39;s permission for a folder | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


